Export Package VRC : bcSCA 22pre 
Update compared VRC:   SCAU2251a 
Only Package       : Yes
Based on sessions  : No
Script sources     : Yes
Function  sources  : Yes
Library sources    : Yes
Total file size    : 4018920
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
b = Functions
h = Help Text Codes
----------------------
qbcstc00001                         SCA 22pre
qbcstc00002                         SCA 22pre
qbcstc00003                         SCA 22pre
qbcstd00001                         SCA 22pre
qbcstf00001                         SCA 22pre
qbcstf00002                         SCA 22pre
qbcstf00003                         SCA 22pre
qbcstf00004                         SCA 22pre
qbcstf00005                         SCA 22pre
dbccdpd                             SCA 22pre
dbccisli.cstt                       SCA 22pre
dbccity                             SCA 22pre
dbcecedi.mess                       SCA 22pre
dbcecedi.orga                       SCA 22pre
dbcgen.utcs                         SCA 22pre
dbcglco                             SCA 22pre
dbcidnr                             SCA 22pre
dbckuia                             SCA 22pre
dbclevel                            SCA 22pre
dbcmcs.rstp                         SCA 22pre
dbcmmas                             SCA 22pre
dbcpcg.modu                         SCA 22pre
dbcpcg.uolp                         SCA 22pre
dbcpref                             SCA 22pre
dbcpstp                             SCA 22pre
dbcpsty                             SCA 22pre
dbcsbp.timc                         SCA 22pre
dbcspto                             SCA 22pre
dbcssa                              SCA 22pre
dbcstc.dtype                        SCA 22pre
dbcstc.gene                         SCA 22pre
dbcstc.keys                         SCA 22pre
dbcstc.stid                         SCA 22pre
dbcstc.taxo                         SCA 22pre
dbcstc.toor                         SCA 22pre
dbcstc.vbon                         SCA 22pre
dbcstd.levl                         SCA 22pre
dbcstd.mpsd                         SCA 22pre
dbcstd.mtyp                         SCA 22pre
dbcstd.tscp                         SCA 22pre
dbcstf.bank                         SCA 22pre
dbcstf.bnid                         SCA 22pre
dbcstf.mgrni                        SCA 22pre
dbcstf.swft                         SCA 22pre
dbcstr.27                           SCA 22pre
dbcstr220                           SCA 22pre
dbcstr3                             SCA 22pre
dbcstr8                             SCA 22pre
dbcsts.cctp                         SCA 22pre
dbcsts.desc                         SCA 22pre
dbctcemno                           SCA 22pre
dbctctype                           SCA 22pre
dbctcuef.mask                       SCA 22pre
dbctdgen.dorg                       SCA 22pre
dbctdgen.porg                       SCA 22pre
dbctdpcg.dsor                       SCA 22pre
dbctdpcg.dssc                       SCA 22pre
dbctdpcg.made                       SCA 22pre
dbctdpcg.maty                       SCA 22pre
dbctdpcg.ndssc                      SCA 22pre
dbctdpcg.nmad                       SCA 22pre
dbctdpcg.nprbk                      SCA 22pre
dbctdpcg.pbor                       SCA 22pre
dbctdpcg.prbk                       SCA 22pre
dbctdsta.attv                       SCA 22pre
dbctfacp.otyp                       SCA 22pre
dbctfgld.amnt                       SCA 22pre
dbctfgld.date                       SCA 22pre
dbctfgld.dbcr                       SCA 22pre
dbctfgld.dimx                       SCA 22pre
dbctfgld.docn                       SCA 22pre
dbctfgld.leac                       SCA 22pre
dbctfgld.lino                       SCA 22pre
dbctfgld.prod                       SCA 22pre
dbctfgld.serl                       SCA 22pre
dbctfgld.srno                       SCA 22pre
dbctfgld.ttyp                       SCA 22pre
dbctfgld.year                       SCA 22pre
dbcticpr.chrt                       SCA 22pre
dbctsmdm.csgr                       SCA 22pre
dbctsmdm.cstp                       SCA 22pre
dbcttaad.clan                       SCA 22pre
dbcttaad.user                       SCA 22pre
dbcttdsca                           SCA 22pre
dbctttxt.buf                        SCA 22pre
dbctttxt.ctxt                       SCA 22pre
dbctttxt.kwrd                       SCA 22pre
dbctttxt.opwd                       SCA 22pre
dbctttxt.seqe                       SCA 22pre
dbctttxt.txtg                       SCA 22pre
dbcttudat                           SCA 22pre
dbcwhinh.shpm                       SCA 22pre
tbcsbp000                           SCA 22pre
tbcsbp001                           SCA 22pre
tbcsci001                           SCA 22pre
tbcsec001                           SCA 22pre
tbcsqm000                           SCA 22pre
tbcstc000                           SCA 22pre
tbcstc001                           SCA 22pre
tbcstc002                           SCA 22pre
tbcstc003                           SCA 22pre
tbcstc004                           SCA 22pre
tbcstc005                           SCA 22pre
tbcstc006                           SCA 22pre
tbcstc007                           SCA 22pre
tbcstc008                           SCA 22pre
tbcstc009                           SCA 22pre
tbcstc010                           SCA 22pre
tbcstc011                           SCA 22pre
tbcstc012                           SCA 22pre
tbcstc015                           SCA 22pre
tbcstd000                           SCA 22pre
tbcstd001                           SCA 22pre
tbcstd002                           SCA 22pre
tbcstd003                           SCA 22pre
tbcstd004                           SCA 22pre
tbcstf000                           SCA 22pre
tbcstf001                           SCA 22pre
tbcstf002                           SCA 22pre
tbcstf003                           SCA 22pre
tbcstf004                           SCA 22pre
tbcstf010                           SCA 22pre
tbcsti001                           SCA 22pre
tbcsti002                           SCA 22pre
tbcsti003                           SCA 22pre
tbcsti004                           SCA 22pre
tbcstp000                           SCA 22pre
tbcsts000                           SCA 22pre
tbcsts001                           SCA 22pre
tbcsts002                           SCA 22pre
tbcsts004                           SCA 22pre
tbcsts005                           SCA 22pre
tbcstt001                           SCA 22pre
tbcstt002                           SCA 22pre
tbcstt003                           SCA 22pre
tbcswh000                           SCA 22pre
tbcswh001                           SCA 22pre
tbcswh002                           SCA 22pre
tbcswh003                           SCA 22pre
sbcgcttest                          SCA 22pre
sbcsbp0100m000                      SCA 22pre
sbcsbp0101m000                      SCA 22pre
sbcsec0101m000                      SCA 22pre
sbcsqm0100m000                      SCA 22pre
sbcstc0100m000                      SCA 22pre
sbcstc0101m000                      SCA 22pre
sbcstc0102m000                      SCA 22pre
sbcstc0103m000                      SCA 22pre
sbcstc0104m000                      SCA 22pre
sbcstc0105m000                      SCA 22pre
sbcstc0106m000                      SCA 22pre
sbcstc0107m000                      SCA 22pre
sbcstc0108m000                      SCA 22pre
sbcstc0109m000                      SCA 22pre
sbcstc0110m000                      SCA 22pre
sbcstc0111m000                      SCA 22pre
sbcstc0112m000                      SCA 22pre
sbcstc0115m000                      SCA 22pre
sbcstc0200m100                      SCA 22pre
sbcstc0200m200                      SCA 22pre
sbcstc0200s000                      SCA 22pre
sbcstc0409m000                      SCA 22pre
sbcstd0100m000                      SCA 22pre
sbcstd0101m000                      SCA 22pre
sbcstd0102m000                      SCA 22pre
sbcstd0103m000                      SCA 22pre
sbcstd0504m000                      SCA 22pre
sbcstf0100m000                      SCA 22pre
sbcstf0101m000                      SCA 22pre
sbcstf0102m000                      SCA 22pre
sbcstf0103m000                      SCA 22pre
sbcstf0104m000                      SCA 22pre
sbcstf0200m000                      SCA 22pre
sbcstf0201m000                      SCA 22pre
sbcsti0101m000                      SCA 22pre
sbcsti0104m000                      SCA 22pre
sbcstp0100m000                      SCA 22pre
sbcsts0100m000                      SCA 22pre
sbcsts0101m000                      SCA 22pre
sbcsts0102m000                      SCA 22pre
sbcsts0104m000                      SCA 22pre
sbcsts0105m000                      SCA 22pre
sbcswh0100m000                      SCA 22pre
sbcswh0501m000                      SCA 22pre
sbcswh0502m000                      SCA 22pre
sbcswh0503m000                      SCA 22pre
pbccnvdebug                         SCA 22pre (with source)
pbcgcttest                          SCA 22pre (with source)
pbcintdll0000                       SCA 22pre (with source)
pbcintdll0001                       SCA 22pre (with source)
pbcintdll0002                       SCA 22pre (with source)
pbcintdll0004                       SCA 22pre (with source)
pbcintdll0005                       SCA 22pre (with source)
pbcintdll0006                       SCA 22pre (with source)
pbcintdll0007                       SCA 22pre (with source)
pbcintdll0008                       SCA 22pre (with source)
pbcintdll0009                       SCA 22pre (with source)
pbcintdll0010                       SCA 22pre (with source)
pbcintdll0011                       SCA 22pre (with source)
pbcintdll0012                       SCA 22pre (with source)
pbcintdll0013                       SCA 22pre (with source)
pbcintdll0014                       SCA 22pre (with source)
pbcrunconvdll                       SCA 22pre (with source)
pbcsbp000                           SCA 22pre (with source)
pbcsbp001                           SCA 22pre (with source)
pbcsbp0100                          SCA 22pre (with source)
pbcsbp0101                          SCA 22pre (with source)
pbcsec001                           SCA 22pre (with source)
pbcsec0101                          SCA 22pre (with source)
pbcsqm000                           SCA 22pre (with source)
pbcsqm0100                          SCA 22pre (with source)
pbcstc000                           SCA 22pre (with source)
pbcstc001                           SCA 22pre (with source)
pbcstc002                           SCA 22pre (with source)
pbcstc003                           SCA 22pre (with source)
pbcstc004                           SCA 22pre (with source)
pbcstc005                           SCA 22pre (with source)
pbcstc006                           SCA 22pre (with source)
pbcstc007                           SCA 22pre (with source)
pbcstc008                           SCA 22pre (with source)
pbcstc009                           SCA 22pre (with source)
pbcstc010                           SCA 22pre (with source)
pbcstc0100                          SCA 22pre (with source)
pbcstc0101                          SCA 22pre (with source)
pbcstc0102                          SCA 22pre (with source)
pbcstc0103                          SCA 22pre (with source)
pbcstc0104                          SCA 22pre (with source)
pbcstc0105                          SCA 22pre (with source)
pbcstc0106                          SCA 22pre (with source)
pbcstc0107                          SCA 22pre (with source)
pbcstc0108                          SCA 22pre (with source)
pbcstc0109                          SCA 22pre (with source)
pbcstc011                           SCA 22pre (with source)
pbcstc0110                          SCA 22pre (with source)
pbcstc0111                          SCA 22pre (with source)
pbcstc0112                          SCA 22pre (with source)
pbcstc0115                          SCA 22pre (with source)
pbcstc012                           SCA 22pre (with source)
pbcstc015                           SCA 22pre (with source)
pbcstc0200                          SCA 22pre (with source)
pbcstc0200_1                        SCA 22pre (with source)
pbcstc0200_2                        SCA 22pre (with source)
pbcstc0409                          SCA 22pre (with source)
pbcstcdll0000                       SCA 22pre (with source)
pbcstcdll0001                       SCA 22pre (with source)
pbcstcdll0002                       SCA 22pre (with source)
pbcstcdll0003                       SCA 22pre (with source)
pbcstcdll0004                       SCA 22pre (with source)
pbcstcdll0005                       SCA 22pre (with source)
pbcstcdll0006                       SCA 22pre (with source)
pbcstcdll0007                       SCA 22pre (with source)
pbcstcdll0008                       SCA 22pre (with source)
pbcstcdll0017                       SCA 22pre (with source)
pbcstd000                           SCA 22pre (with source)
pbcstd001                           SCA 22pre (with source)
pbcstd002                           SCA 22pre (with source)
pbcstd003                           SCA 22pre (with source)
pbcstd004                           SCA 22pre (with source)
pbcstd0100                          SCA 22pre (with source)
pbcstd0101                          SCA 22pre (with source)
pbcstd0102                          SCA 22pre (with source)
pbcstd0103                          SCA 22pre (with source)
pbcstd0504                          SCA 22pre (with source)
pbcstddll0001                       SCA 22pre (with source)
pbcstf000                           SCA 22pre (with source)
pbcstf001                           SCA 22pre (with source)
pbcstf002                           SCA 22pre (with source)
pbcstf003                           SCA 22pre (with source)
pbcstf004                           SCA 22pre (with source)
pbcstf010                           SCA 22pre (with source)
pbcstf0100                          SCA 22pre (with source)
pbcstf0101                          SCA 22pre (with source)
pbcstf0102                          SCA 22pre (with source)
pbcstf0103                          SCA 22pre (with source)
pbcstf0104                          SCA 22pre (with source)
pbcstf0200                          SCA 22pre (with source)
pbcstf0201                          SCA 22pre (with source)
pbcstfdll0002                       SCA 22pre (with source)
pbcstfdll0003                       SCA 22pre (with source)
pbcstfdll0004                       SCA 22pre (with source)
pbcsti001                           SCA 22pre (with source)
pbcsti002                           SCA 22pre (with source)
pbcsti003                           SCA 22pre (with source)
pbcsti004                           SCA 22pre (with source)
pbcsti0101                          SCA 22pre (with source)
pbcsti0104                          SCA 22pre (with source)
pbcstp000                           SCA 22pre (with source)
pbcstp0100                          SCA 22pre (with source)
pbcstpdll0001                       SCA 22pre (with source)
pbcsts000                           SCA 22pre (with source)
pbcsts001                           SCA 22pre (with source)
pbcsts002                           SCA 22pre (with source)
pbcsts004                           SCA 22pre (with source)
pbcsts005                           SCA 22pre (with source)
pbcsts0100                          SCA 22pre (with source)
pbcsts0101                          SCA 22pre (with source)
pbcsts0102                          SCA 22pre (with source)
pbcsts0104                          SCA 22pre (with source)
pbcsts0105                          SCA 22pre (with source)
pbcswh000                           SCA 22pre (with source)
pbcswh001                           SCA 22pre (with source)
pbcswh002                           SCA 22pre (with source)
pbcswh003                           SCA 22pre (with source)
pbcswh0100                          SCA 22pre (with source)
pbcswh0501                          SCA 22pre (with source)
pbcswh0502                          SCA 22pre (with source)
pbcswh0503                          SCA 22pre (with source)
fbcsbp0100m00012                    SCA 22pre
fbcsbp0101m00012                    SCA 22pre
fbcsec0101m00012                    SCA 22pre
fbcsqm0100m00012                    SCA 22pre
fbcstc0100m00012                    SCA 22pre
fbcstc0100m00022                    SCA 22pre
fbcstc0101m00012                    SCA 22pre
fbcstc0102m00012                    SCA 22pre
fbcstc0103m00012                    SCA 22pre
fbcstc0104m00012                    SCA 22pre
fbcstc0105m00012                    SCA 22pre
fbcstc0106m00012                    SCA 22pre
fbcstc0107m00012                    SCA 22pre
fbcstc0108m00012                    SCA 22pre
fbcstc0109m00012                    SCA 22pre
fbcstc0110m00012                    SCA 22pre
fbcstc0111m00012                    SCA 22pre
fbcstc0111m000d2                    SCA 22pre
fbcstc0112m00012                    SCA 22pre
fbcstc0115m00012                    SCA 22pre
fbcstc0200m10012                    SCA 22pre
fbcstc0200m20012                    SCA 22pre
fbcstc0200s00012                    SCA 22pre
fbcstc0205m00012                    SCA 22pre
fbcstc0409m00012                    SCA 22pre
fbcstd0100m00012                    SCA 22pre
fbcstd0100m00022                    SCA 22pre
fbcstd0100m00032                    SCA 22pre
fbcstd0101m00012                    SCA 22pre
fbcstd0102m00012                    SCA 22pre
fbcstd0103m00012                    SCA 22pre
fbcstd0504m00012                    SCA 22pre
fbcstf0100m00012                    SCA 22pre
fbcstf0100m00022                    SCA 22pre
fbcstf0100m00032                    SCA 22pre
fbcstf0100m00042                    SCA 22pre
fbcstf0101m00012                    SCA 22pre
fbcstf0102m00012                    SCA 22pre
fbcstf0103m00012                    SCA 22pre
fbcstf0104m00012                    SCA 22pre
fbcstf0200m00012                    SCA 22pre
fbcstf0201d    2                    SCA 22pre
fbcstf0201m00012                    SCA 22pre
fbcsti0101m00012                    SCA 22pre
fbcsti0104m00012                    SCA 22pre
fbcstp0100m00012                    SCA 22pre
fbcsts0100m00012                    SCA 22pre
fbcsts0100m00022                    SCA 22pre
fbcsts0101m00012                    SCA 22pre
fbcsts0102m00012                    SCA 22pre
fbcsts0104m00012                    SCA 22pre
fbcsts0105m00012                    SCA 22pre
fbcsts0105m00022                    SCA 22pre
fbcsts0105m00032                    SCA 22pre
fbcswh0100m00012                    SCA 22pre
fbcswh0100m00022                    SCA 22pre
fbcswh0501m00012                    SCA 22pre
fbcswh0502m00012                    SCA 22pre
fbcswh0503m00012                    SCA 22pre
rbcsqlbcstf010 2                    SCA 22pre
rbcsqlconv     2                    SCA 22pre
rbcstc0409010002                    SCA 22pre
rbcstcerrorrep 2                    SCA 22pre
cbcsbp00001                         SCA 22pre
cbcsbp00002                         SCA 22pre
cbcstc00000                         SCA 22pre
cbcstc00001                         SCA 22pre
cbcstc00002                         SCA 22pre
cbcstc00002.2                       SCA 22pre
cbcstc00003                         SCA 22pre
cbcstc00004                         SCA 22pre
cbcstc00005                         SCA 22pre
cbcstc00006                         SCA 22pre
cbcstc00007                         SCA 22pre
cbcstc00008                         SCA 22pre
cbcstc00009                         SCA 22pre
cbcstc00010                         SCA 22pre
cbcstc00011                         SCA 22pre
cbcstc00012                         SCA 22pre
cbcstc00013                         SCA 22pre
cbcstc00014                         SCA 22pre
cbcstc00015                         SCA 22pre
cbcstc00016                         SCA 22pre
cbcstc00017                         SCA 22pre
cbcstc00018                         SCA 22pre
cbcstc00019                         SCA 22pre
cbcstc00020                         SCA 22pre
cbcstc00021                         SCA 22pre
cbcstc00022                         SCA 22pre
cbcstc00023                         SCA 22pre
cbcstc00024                         SCA 22pre
cbcstc00025                         SCA 22pre
cbcstc00026                         SCA 22pre
cbcstc00027                         SCA 22pre
cbcstc00032                         SCA 22pre
cbcstc00033                         SCA 22pre
cbcstc00034                         SCA 22pre
cbcstc00035                         SCA 22pre
cbcstc00036                         SCA 22pre
cbcstc00037                         SCA 22pre
cbcstc00038                         SCA 22pre
cbcstc00039                         SCA 22pre
cbcstc00040                         SCA 22pre
cbcstc00041                         SCA 22pre
cbcstc00042                         SCA 22pre
cbcstc00043                         SCA 22pre
cbcstc00044                         SCA 22pre
cbcstc00045                         SCA 22pre
cbcstc00046                         SCA 22pre
cbcstc00047                         SCA 22pre
cbcstc00048                         SCA 22pre
cbcstc00049                         SCA 22pre
cbcstc00050                         SCA 22pre
cbcstc00051                         SCA 22pre
cbcstc00052                         SCA 22pre
cbcstd00001                         SCA 22pre
cbcstd00002                         SCA 22pre
cbcstd00003                         SCA 22pre
cbcstd00004                         SCA 22pre
cbcstd00005                         SCA 22pre
cbcstd00006                         SCA 22pre
cbcstd00007                         SCA 22pre
cbcstd00008                         SCA 22pre
cbcstd00009                         SCA 22pre
cbcstd00010                         SCA 22pre
cbcstf00001                         SCA 22pre
cbcstf00002                         SCA 22pre
cbcstf00003                         SCA 22pre
cbcstf00004                         SCA 22pre
cbcstf00005                         SCA 22pre
cbcstf00006                         SCA 22pre
cbcstf00007                         SCA 22pre
cbcstf00008                         SCA 22pre
cbcstf00009                         SCA 22pre
cbcstf00010                         SCA 22pre
cbcstf00011                         SCA 22pre
cbcstf00012                         SCA 22pre
cbcstf00013                         SCA 22pre
cbcstf00014                         SCA 22pre
cbcstf00015                         SCA 22pre
cbcstf00016                         SCA 22pre
cbcstf00017                         SCA 22pre
cbcstf00040                         SCA 22pre
cbcstf00041                         SCA 22pre
cbcstf00042                         SCA 22pre
cbcstf00043                         SCA 22pre
cbcstf00044                         SCA 22pre
cbcstf00045                         SCA 22pre
cbcsti00001                         SCA 22pre
cbcsti00002                         SCA 22pre
cbcsti00003                         SCA 22pre
cbcsti00004                         SCA 22pre
cbcsti00005                         SCA 22pre
cbcsti00006                         SCA 22pre
cbcstp00001                         SCA 22pre
cbcsts00000                         SCA 22pre
cbcsts00001                         SCA 22pre
cbcsts00002                         SCA 22pre
cbcsts00003                         SCA 22pre
cbcswh00001                         SCA 22pre
cbcswh00002                         SCA 22pre
cbcswh00003                         SCA 22pre
cbcswh00004                         SCA 22pre
cbcswh00005                         SCA 22pre
cbcswh00006                         SCA 22pre
cbcswh00007                         SCA 22pre
cbcswh00008                         SCA 22pre
cbcswhs0001                         SCA 22pre
bbcswh0001                          SCA 22pre (with source)
mbcgctconvert 12                    SCA 22pre
mbcsbp0000100112                    SCA 22pre
mbcsci0000100212                    SCA 22pre
mbcsci0000200112                    SCA 22pre
mbcsec0000100112                    SCA 22pre
mbcsqm0000100112                    SCA 22pre
mbcstc0000000012                    SCA 22pre
mbcstc0000000112                    SCA 22pre
mbcstc0000100112                    SCA 22pre
mbcstc0000200112                    SCA 22pre
mbcstc1000000012                    SCA 22pre
mbcstd0000100112                    SCA 22pre
mbcstd0000100212                    SCA 22pre
mbcstd0000200112                    SCA 22pre
mbcstf0000100112                    SCA 22pre
mbcstf0000100212                    SCA 22pre
mbcstf0000200112                    SCA 22pre
mbcsti0000100112                    SCA 22pre
mbcstp0000100112                    SCA 22pre
mbcstp0000100212                    SCA 22pre
mbcstp0000200112                    SCA 22pre
mbcsts0000100112                    SCA 22pre
mbcsts0000100212                    SCA 22pre
mbcsts0000200112                    SCA 22pre
mbcswh0000100112                    SCA 22pre
mbcswh0000100212                    SCA 22pre
mbcswh0000200112                    SCA 22pre
obccnv0200                          SCA 22pre
obccnv4233                          SCA 22pre
obccnv5106                          SCA 22pre
obccnv5201                          SCA 22pre
obccnv5300                          SCA 22pre
obccnv5301                          SCA 22pre
obccnv5401                          SCA 22pre
obccnv5404                          SCA 22pre
obccnv5406                          SCA 22pre
obccnv5500                          SCA 22pre
obccnv5501                          SCA 22pre
obccnv5503                          SCA 22pre
obccnv6400                          SCA 22pre
obccnv801run                        SCA 22pre
obccnv8101                          SCA 22pre
obccnv8201                          SCA 22pre
obccnv8203                          SCA 22pre
obccnv8211                          SCA 22pre
obccnv8212                          SCA 22pre
obccnv8403                          SCA 22pre
obccnv8502                          SCA 22pre
obccnv8503                          SCA 22pre
obccnv85033                         SCA 22pre
obccnv8506                          SCA 22pre
obccnv8507                          SCA 22pre
obccnv8508                          SCA 22pre
obccnv9190                          SCA 22pre
obccnv9442                          SCA 22pre
obccnvdebug                         SCA 22pre
obccnvdeletedir                     SCA 22pre
obccnvdll0001                       SCA 22pre
obccnvdll9000                       SCA 22pre
obccnvloganalys                     SCA 22pre
obccnvnedat                         SCA 22pre
obccnvnttest                        SCA 22pre
obccnvqryverif                      SCA 22pre
obccnvquerytest                     SCA 22pre
obccnvrmscripts                     SCA 22pre
obccnvsqlhash                       SCA 22pre
obccnvtest1m                        SCA 22pre
obccnvtimezone                      SCA 22pre
obcgct0100                          SCA 22pre
obcgct0103                          SCA 22pre
obcgct0105                          SCA 22pre
obcgct0106                          SCA 22pre
obcgct0203                          SCA 22pre
obcgct1500                          SCA 22pre
obcgct3glsca                        SCA 22pre
obcgct4520                          SCA 22pre
obcgct8271                          SCA 22pre
obcgct8570                          SCA 22pre
obcgct8571                          SCA 22pre
obcgct8572                          SCA 22pre
obcgct9188                          SCA 22pre
obcgct9189                          SCA 22pre
obcgct9190                          SCA 22pre
obcgct9191                          SCA 22pre
obcgct9288                          SCA 22pre
obcgct9291.1                        SCA 22pre
obcgct9291.2                        SCA 22pre
obcgctdll0001                       SCA 22pre
obcgctdllcommon                     SCA 22pre
obcgctdllsca                        SCA 22pre
obcgctgetdesc                       SCA 22pre
obcgcthistory                       SCA 22pre
obcgctobjectgen                     SCA 22pre
obcgcttablinfo                      SCA 22pre
obcgcttest                          SCA 22pre
obcgctzoomtimz                      SCA 22pre
obcintdll0000                       SCA 22pre
obcintdll0001                       SCA 22pre
obcintdll0002                       SCA 22pre
obcintdll0004                       SCA 22pre
obcintdll0005                       SCA 22pre
obcintdll0006                       SCA 22pre
obcintdll0007                       SCA 22pre
obcintdll0008                       SCA 22pre
obcintdll0009                       SCA 22pre
obcintdll0010                       SCA 22pre
obcintdll0011                       SCA 22pre
obcintdll0012                       SCA 22pre
obcintdll0013                       SCA 22pre
obcintdll0014                       SCA 22pre
obcrun0000                          SCA 22pre
obcrun2500                          SCA 22pre
obcrun2501                          SCA 22pre
obcrun2502                          SCA 22pre
obcrun4220                          SCA 22pre
obcrun4520                          SCA 22pre
obcrun9087                          SCA 22pre
obcrun9499                          SCA 22pre
obcrun9599                          SCA 22pre
obcrunalert                         SCA 22pre
obcrunconvdll                       SCA 22pre
obcrundbhash                        SCA 22pre
obcrundbhashdb2                     SCA 22pre
obcrundbhashinf                     SCA 22pre
obcrundll0000                       SCA 22pre
obcrundllcommon                     SCA 22pre
obcrunfill.988                      SCA 22pre
obcruninitrep                       SCA 22pre
obcrunlicense                       SCA 22pre
obcrunntdll                         SCA 22pre
obcrunsqlhash                       SCA 22pre
obcsbp000                           SCA 22pre
obcsbp001                           SCA 22pre
obcsbp0100                          SCA 22pre
obcsbp0101                          SCA 22pre
obcsec001                           SCA 22pre
obcsec0101                          SCA 22pre
obcsqm000                           SCA 22pre
obcsqm0100                          SCA 22pre
obcstc000                           SCA 22pre
obcstc001                           SCA 22pre
obcstc002                           SCA 22pre
obcstc003                           SCA 22pre
obcstc004                           SCA 22pre
obcstc006                           SCA 22pre
obcstc007                           SCA 22pre
obcstc009                           SCA 22pre
obcstc010                           SCA 22pre
obcstc0100                          SCA 22pre
obcstc0101                          SCA 22pre
obcstc0102                          SCA 22pre
obcstc0103                          SCA 22pre
obcstc0104                          SCA 22pre
obcstc0106                          SCA 22pre
obcstc0107                          SCA 22pre
obcstc0109                          SCA 22pre
obcstc011                           SCA 22pre
obcstc0110                          SCA 22pre
obcstc0111                          SCA 22pre
obcstc0112                          SCA 22pre
obcstc0115                          SCA 22pre
obcstc012                           SCA 22pre
obcstc015                           SCA 22pre
obcstc0200                          SCA 22pre
obcstc0200_1                        SCA 22pre
obcstc0200_2                        SCA 22pre
obcstc0409                          SCA 22pre
obcstcdll0000                       SCA 22pre
obcstcdll0001                       SCA 22pre
obcstcdll0002                       SCA 22pre
obcstcdll0003                       SCA 22pre
obcstcdll0004                       SCA 22pre
obcstcdll0005                       SCA 22pre
obcstcdll0006                       SCA 22pre
obcstcdll0008                       SCA 22pre
obcstcdll0017                       SCA 22pre
obcstd000                           SCA 22pre
obcstd001                           SCA 22pre
obcstd002                           SCA 22pre
obcstd003                           SCA 22pre
obcstd004                           SCA 22pre
obcstd0100                          SCA 22pre
obcstd0101                          SCA 22pre
obcstd0102                          SCA 22pre
obcstd0103                          SCA 22pre
obcstd0504                          SCA 22pre
obcstddll0001                       SCA 22pre
obcstf000                           SCA 22pre
obcstf001                           SCA 22pre
obcstf002                           SCA 22pre
obcstf003                           SCA 22pre
obcstf004                           SCA 22pre
obcstf010                           SCA 22pre
obcstf0100                          SCA 22pre
obcstf0101                          SCA 22pre
obcstf0102                          SCA 22pre
obcstf0103                          SCA 22pre
obcstf0104                          SCA 22pre
obcstf0200                          SCA 22pre
obcstf0201                          SCA 22pre
obcsti002                           SCA 22pre
obcsti003                           SCA 22pre
obcsti004                           SCA 22pre
obcsti0101                          SCA 22pre
obcsti0104                          SCA 22pre
obcstp000                           SCA 22pre
obcstp0100                          SCA 22pre
obcstpdll0001                       SCA 22pre
obcsts001                           SCA 22pre
obcsts0100                          SCA 22pre
obcsts0101                          SCA 22pre
obcsts0102                          SCA 22pre
obcsts0104                          SCA 22pre
obcsts0105                          SCA 22pre
obcswh000                           SCA 22pre
obcswh001                           SCA 22pre
obcswh002                           SCA 22pre
obcswh003                           SCA 22pre
obcswh0100                          SCA 22pre
obcswh0501                          SCA 22pre
obcswh0502                          SCA 22pre
obcswh0503                          SCA 22pre
obcsqlbcstf010 2                    SCA 22pre
obcstc0409010002                    SCA 22pre
obcstcerrorrep 2                    SCA 22pre
lbcFFstf0201m000.01                 SCA 22pre
lbcFSbcsec0101m0001                 SCA 22pre
lbcFSsbp0100m0001.0                 SCA 22pre
lbcFSsbp0101m0001.0                 SCA 22pre
lbcFSsqm0100m0000                   SCA 22pre
lbcFSsqm0100m0001                   SCA 22pre
lbcFSstc0100m0001.0                 SCA 22pre
lbcFSstc0100m0001.1                 SCA 22pre
lbcFSstc0105m0001.3                 SCA 22pre
lbcFSstc0105m0001.4                 SCA 22pre
lbcFSstc0105m0001.5                 SCA 22pre
lbcFSstc0105m0001.6                 SCA 22pre
lbcFSstc0106m0001.0                 SCA 22pre
lbcFSstc0115m000.2                  SCA 22pre
lbcFSstf0101m0001.0                 SCA 22pre
lbcFSstf0101m0001.1                 SCA 22pre
lbcFSstf0101m0001.2                 SCA 22pre
lbcFSstf0101m0001.3                 SCA 22pre
lbcFSstf0101m0001.4                 SCA 22pre
lbcFSstf0101m0001.5                 SCA 22pre
lbcFSstf0101m0001.6                 SCA 22pre
lbcFSstf0101m0001.7                 SCA 22pre
lbcFSstf0101m0001.8                 SCA 22pre
lbcFSstf0103m0001.0                 SCA 22pre
lbcFSstf0103m0001.1                 SCA 22pre
lbcFSstf0103m0001.2                 SCA 22pre
lbcFSsti0104m0001.0                 SCA 22pre
lbcFSsti0104m0001.1                 SCA 22pre
lbcFSsts0101m0001.0                 SCA 22pre
lbcFSsts0101m0001.1                 SCA 22pre
lbcbc.lastmoddate                   SCA 22pre
lbcbc.sern                          SCA 22pre
lbcbcsbp000.ccgh                    SCA 22pre
lbcbcsbp000.cuni                    SCA 22pre
lbcbcsbp000.cwoc                    SCA 22pre
lbcbcsbp000.dptc                    SCA 22pre
lbcbcsbp000.laty                    SCA 22pre
lbcbcsbp000.pcyb                    SCA 22pre
lbcbcsbp000.pcyd                    SCA 22pre
lbcbcsbp000.prtc                    SCA 22pre
lbcbcsbp000.prtd                    SCA 22pre
lbcbcsbp000.timc                    SCA 22pre
lbcbcsbp001.dsca                    SCA 22pre
lbcbcsbp001.ntas                    SCA 22pre
lbcbcsbp001.otas                    SCA 22pre
lbcbcsbp001.tabl                    SCA 22pre
lbcbcsci001.ctau                    SCA 22pre
lbcbcsci001.ctyp                    SCA 22pre
lbcbcsci001.cvat                    SCA 22pre
lbcbcsci001.dsca                    SCA 22pre
lbcbcsci001.exno                    SCA 22pre
lbcbcsci001.fcmp                    SCA 22pre
lbcbcsci001.ninv                    SCA 22pre
lbcbcsci001.perc                    SCA 22pre
lbcbcsci001.rcod                    SCA 22pre
lbcbcsci001.taxi                    SCA 22pre
lbcbcsci001.tbah                    SCA 22pre
lbcbcsci001.tbai                    SCA 22pre
lbcbcsci001.ttyp                    SCA 22pre
lbcbcsci001.txah                    SCA 22pre
lbcbcsci001.vatc                    SCA 22pre
lbcbcsec001.cmba                    SCA 22pre
lbcbcsec001.cvsu                    SCA 22pre
lbcbcsec001.mess                    SCA 22pre
lbcbcsec001.ncvs                    SCA 22pre
lbcbcsec001.nmes                    SCA 22pre
lbcbcsec001.norg                    SCA 22pre
lbcbcsec001.orga                    SCA 22pre
lbcbcsqm000.qitg                    SCA 22pre
lbcbcstc.generate                   SCA 22pre
lbcbcstc.mappings                   SCA 22pre
lbcbcstc.parameters                 SCA 22pre
lbcbcstc.sbp                        SCA 22pre
lbcbcstc.sec                        SCA 22pre
lbcbcstc.sqm                        SCA 22pre
lbcbcstc.stc                        SCA 22pre
lbcbcstc.std                        SCA 22pre
lbcbcstc.stf                        SCA 22pre
lbcbcstc.sti                        SCA 22pre
lbcbcstc.stp                        SCA 22pre
lbcbcstc.sts                        SCA 22pre
lbcbcstc.swh                        SCA 22pre
lbcbcstc.to.be.val                  SCA 22pre
lbcbcstc000.dsca                    SCA 22pre
lbcbcstc000.eavt                    SCA 22pre
lbcbcstc000.elog                    SCA 22pre
lbcbcstc000.lmco                    SCA 22pre
lbcbcstc000.lmde                    SCA 22pre
lbcbcstc000.muse                    SCA 22pre
lbcbcstc000.ntax                    SCA 22pre
lbcbcstc000.ntxd                    SCA 22pre
lbcbcstc000.ract                    SCA 22pre
lbcbcstc000.spto                    SCA 22pre
lbcbcstc000.srad                    SCA 22pre
lbcbcstc000.srbp                    SCA 22pre
lbcbcstc000.src1                    SCA 22pre
lbcbcstc000.src2                    SCA 22pre
lbcbcstc000.src3                    SCA 22pre
lbcbcstc000.srcn                    SCA 22pre
lbcbcstc000.stwt                    SCA 22pre
lbcbcstc000.txtg                    SCA 22pre
lbcbcstc000.tzid                    SCA 22pre
lbcbcstc001.pstp                    SCA 22pre
lbcbcstc001.type                    SCA 22pre
lbcbcstc002.appr                    SCA 22pre
lbcbcstc002.cdis                    SCA 22pre
lbcbcstc002.dsca                    SCA 22pre
lbcbcstc002.ncdi                    SCA 22pre
lbcbcstc002.rstp                    SCA 22pre
lbcbcstc002.tabl                    SCA 22pre
lbcbcstc003.nlat                    SCA 22pre
lbcbcstc003.olat                    SCA 22pre
lbcbcstc003.pstp                    SCA 22pre
lbcbcstc003.tabl                    SCA 22pre
lbcbcstc004.nlat                    SCA 22pre
lbcbcstc004.nski                    SCA 22pre
lbcbcstc004.olat                    SCA 22pre
lbcbcstc004.oski                    SCA 22pre
lbcbcstc004.tabl                    SCA 22pre
lbcbcstc005.ccty                    SCA 22pre
lbcbcstc005.city                    SCA 22pre
lbcbcstc005.cste                    SCA 22pre
lbcbcstc005.dsca                    SCA 22pre
lbcbcstc005.idnr                    SCA 22pre
lbcbcstc005.name                    SCA 22pre
lbcbcstc005.namf                    SCA 22pre
lbcbcstc005.pstc                    SCA 22pre
lbcbcstc005.seak                    SCA 22pre
lbcbcstc005.uniq                    SCA 22pre
lbcbcstc006.ccty                    SCA 22pre
lbcbcstc006.cmpl                    SCA 22pre
lbcbcstc006.cvat                    SCA 22pre
lbcbcstc006.smpl                    SCA 22pre
lbcbcstc006.tvat                    SCA 22pre
lbcbcstc007.cora                    SCA 22pre
lbcbcstc007.dsca                    SCA 22pre
lbcbcstc007.nlrc                    SCA 22pre
lbcbcstc007.olrc                    SCA 22pre
lbcbcstc007.sara                    SCA 22pre
lbcbcstc007.tabl                    SCA 22pre
lbcbcstc008.ctxt                    SCA 22pre
lbcbcstc008.dsca                    SCA 22pre
lbcbcstc008.ntas                    SCA 22pre
lbcbcstc008.otas                    SCA 22pre
lbcbcstc008.pkey                    SCA 22pre
lbcbcstc008.sfld                    SCA 22pre
lbcbcstc008.tabl                    SCA 22pre
lbcbcstc008.tfld                    SCA 22pre
lbcbcstc009.bpid                    SCA 22pre
lbcbcstc009.ccty                    SCA 22pre
lbcbcstc009.efdt                    SCA 22pre
lbcbcstc009.exdt                    SCA 22pre
lbcbcstc009.fovn                    SCA 22pre
lbcbcstc009.taxo                    SCA 22pre
lbcbcstc010.bpid                    SCA 22pre
lbcbcstc010.ccur                    SCA 22pre
lbcbcstc010.nama                    SCA 22pre
lbcbcstc010.ofcp                    SCA 22pre
lbcbcstc0101.01                     SCA 22pre
lbcbcstc011.cuni                    SCA 22pre
lbcbcstc011.kitm                    SCA 22pre
lbcbcstc012.ccal                    SCA 22pre
lbcbcstc012.ncal                    SCA 22pre
lbcbcstc015.ccty                    SCA 22pre
lbcbcstc015.fmpt                    SCA 22pre
lbcbcstc015.rgnr                    SCA 22pre
lbcbcstc015.spos                    SCA 22pre
lbcbcstc015.uniq                    SCA 22pre
lbcbcstd000.cdis                    SCA 22pre
lbcbcstd000.citm                    SCA 22pre
lbcbcstd000.comp                    SCA 22pre
lbcbcstd000.cpdt                    SCA 22pre
lbcbcstd000.ddis                    SCA 22pre
lbcbcstd000.mmds                    SCA 22pre
lbcbcstd000.mmmd                    SCA 22pre
lbcbcstd000.mmpb                    SCA 22pre
lbcbcstd000.mpsd                    SCA 22pre
lbcbcstd000.mtyp                    SCA 22pre
lbcbcstd000.ngpr                    SCA 22pre
lbcbcstd000.padc                    SCA 22pre
lbcbcstd000.palv                    SCA 22pre
lbcbcstd000.pcdc                    SCA 22pre
lbcbcstd000.pclv                    SCA 22pre
lbcbcstd000.pfps                    SCA 22pre
lbcbcstd000.pfss                    SCA 22pre
lbcbcstd000.podc                    SCA 22pre
lbcbcstd000.polv                    SCA 22pre
lbcbcstd000.ppbk                    SCA 22pre
lbcbcstd000.ptdc                    SCA 22pre
lbcbcstd000.ptlv                    SCA 22pre
lbcbcstd000.sadc                    SCA 22pre
lbcbcstd000.salv                    SCA 22pre
lbcbcstd000.scdc                    SCA 22pre
lbcbcstd000.sclv                    SCA 22pre
lbcbcstd000.seds                    SCA 22pre
lbcbcstd000.semd                    SCA 22pre
lbcbcstd000.sepb                    SCA 22pre
lbcbcstd000.sodc                    SCA 22pre
lbcbcstd000.solv                    SCA 22pre
lbcbcstd000.spbk                    SCA 22pre
lbcbcstd000.sspr                    SCA 22pre
lbcbcstd000.sssl                    SCA 22pre
lbcbcstd000.stdc                    SCA 22pre
lbcbcstd000.stlv                    SCA 22pre
lbcbcstd000.tscp                    SCA 22pre
lbcbcstd000.uolp                    SCA 22pre
lbcbcstd001.maty                    SCA 22pre
lbcbcstd001.nmad                    SCA 22pre
lbcbcstd001.omad                    SCA 22pre
lbcbcstd002.dsor                    SCA 22pre
lbcbcstd002.ndsc                    SCA 22pre
lbcbcstd002.odsc                    SCA 22pre
lbcbcstd003.modu                    SCA 22pre
lbcbcstd003.npbk                    SCA 22pre
lbcbcstd003.opbk                    SCA 22pre
lbcbcstd003.pbor                    SCA 22pre
lbcbcstd004.lseq                    SCA 22pre
lbcbcstd004.nsqn                    SCA 22pre
lbcbcstd004.oltp                    SCA 22pre
lbcbcstd004.orno                    SCA 22pre
lbcbcstd004.oseq                    SCA 22pre
lbcbcstd004.osqn                    SCA 22pre
lbcbcstd004.pono                    SCA 22pre
lbcbcstd004.shpm                    SCA 22pre
lbcbcstf000.aacp                    SCA 22pre
lbcbcstf000.afco                    SCA 22pre
lbcbcstf000.aiab                    SCA 22pre
lbcbcstf000.aocu                    SCA 22pre
lbcbcstf000.aosu                    SCA 22pre
lbcbcstf000.aotc                    SCA 22pre
lbcbcstf000.aots                    SCA 22pre
lbcbcstf000.apar                    SCA 22pre
lbcbcstf000.apbb                    SCA 22pre
lbcbcstf000.aptb                    SCA 22pre
lbcbcstf000.brel                    SCA 22pre
lbcbcstf000.cban                    SCA 22pre
lbcbcstf000.fban                    SCA 22pre
lbcbcstf000.iasb                    SCA 22pre
lbcbcstf000.legd                    SCA 22pre
lbcbcstf000.legl                    SCA 22pre
lbcbcstf000.mgdt                    SCA 22pre
lbcbcstf000.mgpc                    SCA 22pre
lbcbcstf000.mgpu                    SCA 22pre
lbcbcstf000.mgrn                    SCA 22pre
lbcbcstf000.mgsu                    SCA 22pre
lbcbcstf000.mgtr                    SCA 22pre
lbcbcstf000.ocsa                    SCA 22pre
lbcbcstf000.ocus                    SCA 22pre
lbcbcstf000.ospa                    SCA 22pre
lbcbcstf000.osup                    SCA 22pre
lbcbcstf000.sban                    SCA 22pre
lbcbcstf000.sttf                    SCA 22pre
lbcbcstf000.stth                    SCA 22pre
lbcbcstf001.badr                    SCA 22pre
lbcbcstf001.bank                    SCA 22pre
lbcbcstf001.bnid                    SCA 22pre
lbcbcstf001.btyp                    SCA 22pre
lbcbcstf001.cbad                    SCA 22pre
lbcbcstf001.keys                    SCA 22pre
lbcbcstf001.reqd                    SCA 22pre
lbcbcstf001.tabl                    SCA 22pre
lbcbcstf002.actv                    SCA 22pre
lbcbcstf002.badr                    SCA 22pre
lbcbcstf002.bank                    SCA 22pre
lbcbcstf002.bnid                    SCA 22pre
lbcbcstf002.btyp                    SCA 22pre
lbcbcstf002.cbad                    SCA 22pre
lbcbcstf002.comp                    SCA 22pre
lbcbcstf002.dim1                    SCA 22pre
lbcbcstf002.dim2                    SCA 22pre
lbcbcstf002.dim3                    SCA 22pre
lbcbcstf002.dim4                    SCA 22pre
lbcbcstf002.dim5                    SCA 22pre
lbcbcstf002.glcd                    SCA 22pre
lbcbcstf002.keys                    SCA 22pre
lbcbcstf002.leac                    SCA 22pre
lbcbcstf002.reqd                    SCA 22pre
lbcbcstf002.tabl                    SCA 22pre
lbcbcstf003.cdca                    SCA 22pre
lbcbcstf003.leac                    SCA 22pre
lbcbcstf003.tabl                    SCA 22pre
lbcbcstf003.uia4                    SCA 22pre
lbcbcstf003.uia6                    SCA 22pre
lbcbcstf004.cdca                    SCA 22pre
lbcbcstf004.desc                    SCA 22pre
lbcbcstf010.acce                    SCA 22pre
lbcbcstf010.accf                    SCA 22pre
lbcbcstf010.amnt                    SCA 22pre
lbcbcstf010.amth                    SCA 22pre
lbcbcstf010.ccur                    SCA 22pre
lbcbcstf010.core                    SCA 22pre
lbcbcstf010.cuni                    SCA 22pre
lbcbcstf010.dbcr                    SCA 22pre
lbcbcstf010.dcdt                    SCA 22pre
lbcbcstf010.edes                    SCA 22pre
lbcbcstf010.erro                    SCA 22pre
lbcbcstf010.fprd                    SCA 22pre
lbcbcstf010.fyer                    SCA 22pre
lbcbcstf010.lino                    SCA 22pre
lbcbcstf010.nuni                    SCA 22pre
lbcbcstf010.ocmp                    SCA 22pre
lbcbcstf010.orno                    SCA 22pre
lbcbcstf010.otyp                    SCA 22pre
lbcbcstf010.pono                    SCA 22pre
lbcbcstf010.proj                    SCA 22pre
lbcbcstf010.serl                    SCA 22pre
lbcbcstf010.srno                    SCA 22pre
lbcbcstf010.tmpk                    SCA 22pre
lbcbcstf0100.01                     SCA 22pre
lbcbcstf0100.02                     SCA 22pre
lbcbcstf0100.03                     SCA 22pre
lbcbcstf0100.04                     SCA 22pre
lbcbcstf0100.05                     SCA 22pre
lbcbcstf0100.06                     SCA 22pre
lbcbcstf0100.07                     SCA 22pre
lbcbcstf0201.01                     SCA 22pre
lbcbcsti001.chrt                    SCA 22pre
lbcbcsti001.item                    SCA 22pre
lbcbcsti001.leve                    SCA 22pre
lbcbcsti002.desc                    SCA 22pre
lbcbcsti002.nocp                    SCA 22pre
lbcbcsti003.cpcp                    SCA 22pre
lbcbcsti004.amnt                    SCA 22pre
lbcbcsti004.cpcp                    SCA 22pre
lbcbcsti004.cwoc                    SCA 22pre
lbcbcsti004.mcno                    SCA 22pre
lbcbcsti004.smcn                    SCA 22pre
lbcbcsti004.tano                    SCA 22pre
lbcbcsti005.cpcp                    SCA 22pre
lbcbcsti005.decp                    SCA 22pre
lbcbcsti005.orno                    SCA 22pre
lbcbcsti005.spit                    SCA 22pre
lbcbcsti005.stwh                    SCA 22pre
lbcbcsti005.vpwh                    SCA 22pre
lbcbcsti006.afat                    SCA 22pre
lbcbcsti006.avat                    SCA 22pre
lbcbcsti006.cpcp                    SCA 22pre
lbcbcsti006.tfat                    SCA 22pre
lbcbcsti006.tvat                    SCA 22pre
lbcbcsti007.base                    SCA 22pre
lbcbcsti007.chcp                    SCA 22pre
lbcbcsti007.chpr                    SCA 22pre
lbcbcsti007.cmth                    SCA 22pre
lbcbcsti007.cpch                    SCA 22pre
lbcbcsti007.cpcp                    SCA 22pre
lbcbcsti007.cwar                    SCA 22pre
lbcbcsti007.kocl                    SCA 22pre
lbcbcsti007.remo                    SCA 22pre
lbcbcsti007.vaco                    SCA 22pre
lbcbcsti008.cpcp                    SCA 22pre
lbcbcsti009.cpcp                    SCA 22pre
lbcbcsti009.issa                    SCA 22pre
lbcbcsti009.issf                    SCA 22pre
lbcbcsti009.issv                    SCA 22pre
lbcbcsti009.reca                    SCA 22pre
lbcbcsti009.recf                    SCA 22pre
lbcbcsti009.recv                    SCA 22pre
lbcbcsti010.agcp                    SCA 22pre
lbcbcsti010.cpcp                    SCA 22pre
lbcbcsti0101.01                     SCA 22pre
lbcbcstp000.ccur                    SCA 22pre
lbcbcstp000.cprj                    SCA 22pre
lbcbcstp000.padr                    SCA 22pre
lbcbcstp000.rtyp                    SCA 22pre
lbcbcstp000.unit                    SCA 22pre
lbcbcsts.time.units                 SCA 22pre
lbcbcsts000.bfbp                    SCA 22pre
lbcbcsts000.cagr                    SCA 22pre
lbcbcsts000.call                    SCA 22pre
lbcbcsts000.ccte                    SCA 22pre
lbcbcsts000.ckgr                    SCA 22pre
lbcbcsts000.cpcp                    SCA 22pre
lbcbcsts000.csgr                    SCA 22pre
lbcbcsts000.cstp                    SCA 22pre
lbcbcsts000.ctin                    SCA 22pre
lbcbcsts000.dtin                    SCA 22pre
lbcbcsts000.fcho                    SCA 22pre
lbcbcsts000.insp                    SCA 22pre
lbcbcsts000.logn                    SCA 22pre
lbcbcsts000.msor                    SCA 22pre
lbcbcsts000.plac                    SCA 22pre
lbcbcsts000.ract                    SCA 22pre
lbcbcsts000.soqu                    SCA 22pre
lbcbcsts000.trfu                    SCA 22pre
lbcbcsts000.uagr                    SCA 22pre
lbcbcsts000.uday                    SCA 22pre
lbcbcsts000.uhou                    SCA 22pre
lbcbcsts000.umin                    SCA 22pre
lbcbcsts000.usec                    SCA 22pre
lbcbcsts001.cctp                    SCA 22pre
lbcbcsts001.cstp                    SCA 22pre
lbcbcsts002.item                    SCA 22pre
lbcbcsts002.sern                    SCA 22pre
lbcbcsts004.apid                    SCA 22pre
lbcbcsts004.appl                    SCA 22pre
lbcbcsts004.item                    SCA 22pre
lbcbcsts004.sern                    SCA 22pre
lbcbcsts004.term                    SCA 22pre
lbcbcsts005.amnt                    SCA 22pre
lbcbcsts005.apid                    SCA 22pre
lbcbcsts005.camt                    SCA 22pre
lbcbcsts005.ccbn                    SCA 22pre
lbcbcsts005.ccfg                    SCA 22pre
lbcbcsts005.cfln                    SCA 22pre
lbcbcsts005.item                    SCA 22pre
lbcbcsts005.quan                    SCA 22pre
lbcbcsts005.seqn                    SCA 22pre
lbcbcsts005.stbl                    SCA 22pre
lbcbcsts005.term                    SCA 22pre
lbcbcsts005.type                    SCA 22pre
lbcbcsts0100.01                     SCA 22pre
lbcbcstt001.cttxt                   SCA 22pre
lbcbcstt001.ctxt                    SCA 22pre
lbcbcstt001.desc                    SCA 22pre
lbcbcstt001.opwd                    SCA 22pre
lbcbcstt001.txtg                    SCA 22pre
lbcbcstt002.clan                    SCA 22pre
lbcbcstt002.kwd1                    SCA 22pre
lbcbcstt002.kwd2                    SCA 22pre
lbcbcstt002.kwd3                    SCA 22pre
lbcbcstt002.kwd4                    SCA 22pre
lbcbcstt002.ludt                    SCA 22pre
lbcbcstt002.nlin                    SCA 22pre
lbcbcstt002.user                    SCA 22pre
lbcbcstt003.text                    SCA 22pre
lbcbcstt004.ctxt                    SCA 22pre
lbcbcstt004.desc                    SCA 22pre
lbcbcstt004.opwd                    SCA 22pre
lbcbcstt004.txtg                    SCA 22pre
lbcbcstt005.ctxt                    SCA 22pre
lbcbcstt005.desc                    SCA 22pre
lbcbcstt005.opwd                    SCA 22pre
lbcbcstt005.txtg                    SCA 22pre
lbcbcstt006.text                    SCA 22pre
lbcbcswh000.acsr                    SCA 22pre
lbcbcswh000.adng                    SCA 22pre
lbcbcswh000.adsr                    SCA 22pre
lbcbcswh000.aisr                    SCA 22pre
lbcbcswh000.aosr                    SCA 22pre
lbcbcswh000.apng                    SCA 22pre
lbcbcswh000.ccng                    SCA 22pre
lbcbcswh000.ccsr                    SCA 22pre
lbcbcswh000.cdng                    SCA 22pre
lbcbcswh000.cdsr                    SCA 22pre
lbcbcswh000.cwar                    SCA 22pre
lbcbcswh000.dnng                    SCA 22pre
lbcbcswh000.dnsr                    SCA 22pre
lbcbcswh000.iang                    SCA 22pre
lbcbcswh000.iasr                    SCA 22pre
lbcbcswh000.mcsr                    SCA 22pre
lbcbcswh000.nrgr                    SCA 22pre
lbcbcswh000.rcph                    SCA 22pre
lbcbcswh000.rcpt                    SCA 22pre
lbcbcswh000.resr                    SCA 22pre
lbcbcswh000.rssi                    SCA 22pre
lbcbcswh000.rvds                    SCA 22pre
lbcbcswh000.rvrs                    SCA 22pre
lbcbcswh000.seri                    SCA 22pre
lbcbcswh000.vmsr                    SCA 22pre
lbcbcswh001.nrcn                    SCA 22pre
lbcbcswh001.oorg                    SCA 22pre
lbcbcswh001.orno                    SCA 22pre
lbcbcswh001.pono                    SCA 22pre
lbcbcswh001.rcln                    SCA 22pre
lbcbcswh001.rcno                    SCA 22pre
lbcbcswh001.seqn                    SCA 22pre
lbcbcswh002.apno                    SCA 22pre
lbcbcswh002.apnr                    SCA 22pre
lbcbcswh002.apsq                    SCA 22pre
lbcbcswh002.oorg                    SCA 22pre
lbcbcswh002.orno                    SCA 22pre
lbcbcswh002.pono                    SCA 22pre
lbcbcswh002.seqn                    SCA 22pre
lbcbcswh002.sern                    SCA 22pre
lbcbcswh003.cdol                    SCA 22pre
lbcbcswh003.cdor                    SCA 22pre
lbcbcswh003.porn                    SCA 22pre
lbcbcswh003.ppon                    SCA 22pre
lbcbcswh003.pseq                    SCA 22pre
lbcbcswh003.sorn                    SCA 22pre
lbcbcswh003.spon                    SCA 22pre
lbcbcswh003.sseq                    SCA 22pre
lbcbstc0100.01                      SCA 22pre
lbcbstc0100.02                      SCA 22pre
lbcbstc0100.03                      SCA 22pre
lbcstf0200.01                       SCA 22pre
lbctcgen.from                       SCA 22pre
lbctcgen.pono                       SCA 22pre
lbctcgen.selec.range                SCA 22pre
lbctcgen.to                         SCA 22pre
lbctcitem                           SCA 22pre
lbcttgen.from                       SCA 22pre
lbcttgen.h.comp                     SCA 22pre
lbcttgen.h.date                     SCA 22pre
lbcttgen.page                       SCA 22pre
lbcttgen.print                      SCA 22pre
lbcttgen.to                         SCA 22pre
lbcttgen.yesno                      SCA 22pre
lbcwhinh200.oorg                    SCA 22pre
lbcwhinh200.orno                    SCA 22pre
Fbccnv0200s00012                    SCA 22pre
Fbccnv0200s000d2                    SCA 22pre
Fbccnv02991    2                    SCA 22pre
Fbccnv0299m00012                    SCA 22pre
Fbccnv0401m00012                    SCA 22pre
Fbccnv0401m000d2                    SCA 22pre
Fbccnv250m0001 2                    SCA 22pre
Fbccnv42231    2                    SCA 22pre
Fbccnv4223m00012                    SCA 22pre
Fbccnv4233m00012                    SCA 22pre
Fbccnv4233m000d2                    SCA 22pre
Fbccnv4520m00012                    SCA 22pre
Fbccnv5100m00012                    SCA 22pre
Fbccnv5100m000d2                    SCA 22pre
Fbccnv5106m00012                    SCA 22pre
Fbccnv5106m000d2                    SCA 22pre
Fbccnv5201m00012                    SCA 22pre
Fbccnv5201m000d2                    SCA 22pre
Fbccnv5300m00012                    SCA 22pre
Fbccnv5300m000d2                    SCA 22pre
Fbccnv5301m00012                    SCA 22pre
Fbccnv5301m000d2                    SCA 22pre
Fbccnv5401m00012                    SCA 22pre
Fbccnv5401m000d2                    SCA 22pre
Fbccnv5404m00012                    SCA 22pre
Fbccnv5404m000d2                    SCA 22pre
Fbccnv5500m00012                    SCA 22pre
Fbccnv5500m000d2                    SCA 22pre
Fbccnv5501m00012                    SCA 22pre
Fbccnv5501m00022                    SCA 22pre
Fbccnv5501m000d2                    SCA 22pre
Fbccnv5503m000d2                    SCA 22pre
Fbccnv6400m00012                    SCA 22pre
Fbccnv6400m000d2                    SCA 22pre
Fbccnv8101m00012                    SCA 22pre
Fbccnv8101m000d2                    SCA 22pre
Fbccnv8201m00012                    SCA 22pre
Fbccnv8201s00012                    SCA 22pre
Fbccnv8201s000d2                    SCA 22pre
Fbccnv8201s00112                    SCA 22pre
Fbccnv8201s00212                    SCA 22pre
Fbccnv8201s002d2                    SCA 22pre
Fbccnv8203m00012                    SCA 22pre
Fbccnv8203m000d2                    SCA 22pre
Fbccnv8403m00012                    SCA 22pre
Fbccnv8403m000d2                    SCA 22pre
Fbccnv8403m00112                    SCA 22pre
Fbccnv8403m00212                    SCA 22pre
Fbccnv8498m00012                    SCA 22pre
Fbccnv8502m00012                    SCA 22pre
Fbccnv8502m000d2                    SCA 22pre
Fbccnv85031    2                    SCA 22pre
Fbccnv85032    2                    SCA 22pre
Fbccnv85033    2                    SCA 22pre
Fbccnv85034    2                    SCA 22pre
Fbccnv8503m00012                    SCA 22pre
Fbccnv8503m000d2                    SCA 22pre
Fbccnv8503m00112                    SCA 22pre
Fbccnv8503s00212                    SCA 22pre
Fbccnv8503s002d2                    SCA 22pre
Fbccnv8503s00312                    SCA 22pre
Fbccnv8506s00012                    SCA 22pre
Fbccnv8506s000d2                    SCA 22pre
Fbccnv8507s00012                    SCA 22pre
Fbccnv8507s000d2                    SCA 22pre
Fbccnv8508s00012                    SCA 22pre
Fbccnv8508s000d2                    SCA 22pre
Fbccnv91051    2                    SCA 22pre
Fbccnv91801    2                    SCA 22pre
Fbccnv9180s00012                    SCA 22pre
Fbccnv9181m00012                    SCA 22pre
Fbccnv9181s00012                    SCA 22pre
Fbccnv9182m00012                    SCA 22pre
Fbccnv9442m00012                    SCA 22pre
Fbccnv9442m000d2                    SCA 22pre
Fbccnv9582m00012                    SCA 22pre
Fbccnvdebug    2                    SCA 22pre
Fbcgct0100m00022                    SCA 22pre
Fbcgct0100m00032                    SCA 22pre
Fbcgct0100m000d2                    SCA 22pre
Fbcgct0101m00022                    SCA 22pre
Fbcgct0103m00012                    SCA 22pre
Fbcgct0103m000d2                    SCA 22pre
Fbcgct0105s00012                    SCA 22pre
Fbcgct0105s000d2                    SCA 22pre
Fbcgct0106m00012                    SCA 22pre
Fbcgct0106m000d2                    SCA 22pre
Fbcgct0203s00012                    SCA 22pre
Fbcgct0203s000d2                    SCA 22pre
Fbcgct1500m000d2                    SCA 22pre
Fbcgct4520m000d2                    SCA 22pre
Fbcgct5103m00012                    SCA 22pre
Fbcgct8170m00012                    SCA 22pre
Fbcgct8170m00022                    SCA 22pre
Fbcgct8271m00012                    SCA 22pre
Fbcgct8271m000d2                    SCA 22pre
Fbcgct8570m000d2                    SCA 22pre
Fbcgct8571m00012                    SCA 22pre
Fbcgct8571m00022                    SCA 22pre
Fbcgct8571m00032                    SCA 22pre
Fbcgct8571m00042                    SCA 22pre
Fbcgct8571m000d2                    SCA 22pre
Fbcgct8571m00212                    SCA 22pre
Fbcgct8571m11112                    SCA 22pre
Fbcgct8571m22222                    SCA 22pre
Fbcgct8572m00012                    SCA 22pre
Fbcgct8572m000d2                    SCA 22pre
Fbcgct9188m00012                    SCA 22pre
Fbcgct9188m000d2                    SCA 22pre
Fbcgct9189m00012                    SCA 22pre
Fbcgct9189m000d2                    SCA 22pre
Fbcgct91901    2                    SCA 22pre
Fbcgct9190m00012                    SCA 22pre
Fbcgct9190m000d2                    SCA 22pre
Fbcgct9191m00012                    SCA 22pre
Fbcgct9191m000d2                    SCA 22pre
Fbcgct9288m000 2                    SCA 22pre
Fbcgct9288m000d2                    SCA 22pre
Fbcgct9291m10012                    SCA 22pre
Fbcgct9291m100d2                    SCA 22pre
Fbcgct9291m20012                    SCA 22pre
Fbcgct9291m200d2                    SCA 22pre
Fbcgct9585m00012                    SCA 22pre
Fbcgct9585m000d2                    SCA 22pre
Fbcrun0000m00012                    SCA 22pre
Fbcrun0300m00012                    SCA 22pre
Fbcrun0300m000d2                    SCA 22pre
Fbcrun2500m00012                    SCA 22pre
Fbcrun2500m000d2                    SCA 22pre
Fbcrun2501m00012                    SCA 22pre
Fbcrun2501m000d2                    SCA 22pre
Fbcrun2502m00012                    SCA 22pre
Fbcrun2502m000d2                    SCA 22pre
Fbcrun4220m00012                    SCA 22pre
Fbcrun4220m00022                    SCA 22pre
Fbcrun4220m000d2                    SCA 22pre
Fbcrun4520m00022                    SCA 22pre
Fbcrun4520m000d2                    SCA 22pre
Fbcrun5125m00012                    SCA 22pre
Fbcrun9087m00022                    SCA 22pre
Fbcrun9499m00012                    SCA 22pre
Fbcrun9499m000d2                    SCA 22pre
Fbcrun9599m00012                    SCA 22pre
Fbcrun9599m000d2                    SCA 22pre
Fbcsbp0100m00012                    SCA 22pre
Fbcsbp0101m00012                    SCA 22pre
Fbcsec0101m00012                    SCA 22pre
Fbcsqm0100m00012                    SCA 22pre
Fbcstc0100m00012                    SCA 22pre
Fbcstc0100m00022                    SCA 22pre
Fbcstc0101m00012                    SCA 22pre
Fbcstc0102m00012                    SCA 22pre
Fbcstc0103m00012                    SCA 22pre
Fbcstc0104m00012                    SCA 22pre
Fbcstc0106m00012                    SCA 22pre
Fbcstc0107m00012                    SCA 22pre
Fbcstc0108m00012                    SCA 22pre
Fbcstc0109m00012                    SCA 22pre
Fbcstc0110m00012                    SCA 22pre
Fbcstc0111m00012                    SCA 22pre
Fbcstc0111m000d2                    SCA 22pre
Fbcstc0112m00012                    SCA 22pre
Fbcstc0115m00012                    SCA 22pre
Fbcstc0200m10012                    SCA 22pre
Fbcstc0200m20012                    SCA 22pre
Fbcstc0200s00012                    SCA 22pre
Fbcstc0205m00012                    SCA 22pre
Fbcstc0409m00012                    SCA 22pre
Fbcstd0100m00012                    SCA 22pre
Fbcstd0100m00022                    SCA 22pre
Fbcstd0100m00032                    SCA 22pre
Fbcstd0101m00012                    SCA 22pre
Fbcstd0102m00012                    SCA 22pre
Fbcstd0103m00012                    SCA 22pre
Fbcstd0504m00012                    SCA 22pre
Fbcstf0100m00012                    SCA 22pre
Fbcstf0100m00022                    SCA 22pre
Fbcstf0100m00032                    SCA 22pre
Fbcstf0100m00042                    SCA 22pre
Fbcstf0101m00012                    SCA 22pre
Fbcstf0102m00012                    SCA 22pre
Fbcstf0103m00012                    SCA 22pre
Fbcstf0104m00012                    SCA 22pre
Fbcstf0200m00012                    SCA 22pre
Fbcstf0201m00012                    SCA 22pre
Fbcsti0101m00012                    SCA 22pre
Fbcsti0104m00012                    SCA 22pre
Fbcstp0100m00012                    SCA 22pre
Fbcsts0100m00012                    SCA 22pre
Fbcsts0100m00022                    SCA 22pre
Fbcsts0101m00012                    SCA 22pre
Fbcsts0102m00012                    SCA 22pre
Fbcsts0104m00012                    SCA 22pre
Fbcsts0105m00012                    SCA 22pre
Fbcsts0105m00022                    SCA 22pre
Fbcsts0105m00032                    SCA 22pre
Fbcswh0100m00012                    SCA 22pre
Fbcswh0100m00022                    SCA 22pre
Fbcswh0501m00012                    SCA 22pre
Fbcswh0502m00012                    SCA 22pre
Fbcswh0503m00012                    SCA 22pre
Mbccnvdebug   12                    SCA 22pre
Mbccnvsimulate12                    SCA 22pre
Mbcgctchecklst12                    SCA 22pre
Mbcgctconvert 12                    SCA 22pre
Mbcgctesetup  12                    SCA 22pre
Mbcgctprocedur12                    SCA 22pre
Mbcgctprocess 12                    SCA 22pre
Mbcgctreports 12                    SCA 22pre
Mbcgctutility112                    SCA 22pre
Mbcgctutility212                    SCA 22pre
Mbcsbp0000100112                    SCA 22pre
Mbcsci0000100212                    SCA 22pre
Mbcsci0000200112                    SCA 22pre
Mbcsec0000100112                    SCA 22pre
Mbcsqm0000100112                    SCA 22pre
Mbcstc0000000012                    SCA 22pre
Mbcstc0000000112                    SCA 22pre
Mbcstc0000100112                    SCA 22pre
Mbcstc1000000012                    SCA 22pre
Mbcstd0000100112                    SCA 22pre
Mbcstd0000100212                    SCA 22pre
Mbcstd0000200112                    SCA 22pre
Mbcstf0000100112                    SCA 22pre
Mbcstf0000100212                    SCA 22pre
Mbcstf0000200112                    SCA 22pre
Mbcsti0000100112                    SCA 22pre
Mbcstp0000100112                    SCA 22pre
Mbcstp0000100212                    SCA 22pre
Mbcstp0000200112                    SCA 22pre
Mbcsts0000100112                    SCA 22pre
Mbcsts0000100212                    SCA 22pre
Mbcsts0000200112                    SCA 22pre
Mbcswh0000100112                    SCA 22pre
Mbcswh0000100212                    SCA 22pre
Mbcswh0000200112                    SCA 22pre
